@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from hubspot.cms.site_search.api.default_api import DefaultApi
+from hubspot.cms.site_search.api.public_api import PublicApi
