@@ -3,9 +3,7 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from hubspot.crm.objects.feedback_submissions.api.associations_api import (
-    AssociationsApi,
-)
+from hubspot.crm.objects.feedback_submissions.api.associations_api import AssociationsApi
 from hubspot.crm.objects.feedback_submissions.api.basic_api import BasicApi
 from hubspot.crm.objects.feedback_submissions.api.batch_api import BatchApi
 from hubspot.crm.objects.feedback_submissions.api.search_api import SearchApi
