@@ -4,5 +4,5 @@ from ....discovery_base import DiscoveryBase
 
 class Discovery(DiscoveryBase):
     @property
-    def default_api(self) -> api_client.DefaultApi:
-        return self._configure_api_client(api_client, "DefaultApi")
+    def blog_post_api(self) -> api_client.BlogPostApi:
+        return self._configure_api_client(api_client, "BlogPostApi")
